@@ -9,8 +9,9 @@ remove=echo 'destroying...'
 activate=echo 'activating...'
 deactivate=echo 'deactivating...'
 """
+from __future__ import unicode_literals
 from sprinter.formulabase import FormulaBase
-from sprinter import lib
+import sprinter.lib as lib
 
 
 class CommandFormula(FormulaBase):
