@@ -7,11 +7,12 @@ url = https://github.com/toumorokoshi/sub.git
 branch = toumorokoshi
 rc = . %(sub:root_dir)s/libexec/sub-init
 """
+from __future__ import unicode_literals
 import logging
 import os
 
 from sprinter.formulabase import FormulaBase
-from sprinter import lib
+import sprinter.lib as lib
 
 
 class GitException(Exception):
